@@ -1,10 +1,10 @@
 """ Python 3D FDTD Simulator """
 
 __author__ = "Floris laporte"
-__version__ = "0.0.1"
+__version__ = "0.0.2"
 
 from .grid import Grid
-from .sources import PointSource, LineSource
+from .sources import PointSource, LineSource, PlaneSource
 from .detectors import LineDetector
 from .objects import Object, AbsorbingObject, AnisotropicObject
 from .boundaries import PeriodicBoundary, PML
